hive library

Classes

AdapterSpec<T>
Configuration that specifies the generation of a TypeAdapter
BinaryReader
The BinaryReader is used to bring data back from the binary format on the disk.
BinaryWriter
The BinaryWriter is used to encode data to the binary format.
Box<E>
Boxes contain all of your data. In the browser, each box has its own IndexedDB database. On all other platforms, each Box is stored in a separate file in the Hive home directory.
BoxBase<E>
Boxes contain all of your data. In the browser, each box has its own IndexedDB database. On all other platforms, each Box is stored in a seperate file in the Hive home directory.
BoxCollection
TODO: Document this!
BoxEvent
A event representing a change in a box.
CollectionBox<V>
represents a Box being part of a BoxCollection
GenerateAdapters
Annotation to generate TypeAdapters for the given specs
HiveAesCipher
Default encryption algorithm. Uses AES256 CBC with PKCS7 padding.
HiveCipher
Abstract cipher can be implemented to customize encryption.
HiveCollection<E extends HiveObjectMixin>
List containing HiveObjectMixins.
HiveField
Annotate all fields you want to persist with HiveField.
HiveInterface
The main API interface of Hive. Available through the Hive constant.
HiveList<E extends HiveObjectMixin>
Allows defining references to other HiveObjectMixins.
HiveObject
TODO: Document this!
HiveType
Annotate classes with HiveType to generate a TypeAdapter.
IsolatedBox<E>
Isolated version of Box
IsolatedBoxBase<E>
Isolated version of BoxBase
IsolatedCompactionStrategy
A sendable description of a CompactionStrategy
IsolatedHiveInterface
Interface for IsolatedHive
IsolatedLazyBox<E>
Isolated version of LazyBox
IsolateNameServer
An abstraction of the IsolateNameServer
LazyBox<E>
LazyBoxes don't keep the values in memory like normal boxes. Each time a value is read, it is loaded from the backend.
TypeAdapter<T>
Type adapters can be implemented to support non primitive values.
TypeRegistry
TypeRegistries contain the TypeAdapters associated with a typeId.

Enums

HiveStorageBackendPreference
declares the preferred JS StorageBackend to be used

Mixins

HiveObjectMixin
Extend HiveObject to add useful methods to the objects you want to store in Hive

Properties

Hive → HiveInterface
Global constant to access Hive
final
IsolatedHive → IsolatedHiveInterface
Global constant to access IsolatedHive
final

Typedefs

CompactionStrategy = bool Function(int entries, int deletedEntries)
A function which decides when to compact a box.
HiveLogger = Logger
Hive's logger
HiveLoggerLevel = LoggerLevel
Hive's logger level
KeyComparator = int Function(dynamic key1, dynamic key2)

Exceptions / Errors

HiveError
An error related to Hive.